"use client";

import React, { useEffect, useState } from 'react';
import { FaStar } from 'react-icons/fa';
import Link from 'next/link';

interface NetworkPageProps {
  networkId: number;
}

interface Network {
  id: number;
  name: string;
  logo_path: string;
}

interface MediaItem {
  id: number;
  name: string;
  poster_path: string;
  vote_average: number;
  media_type: string; // Will always be 'tv' for this component
}

const NetworkPage: React.FC<NetworkPageProps> = ({ networkId }) => {
  const [network, setNetwork] = useState<Network | null>(null);
  const [mediaItems, setMediaItems] = useState<MediaItem[]>([]);
  const [filteredItems, setFilteredItems] = useState<MediaItem[]>([]);
  const [searchQuery, setSearchQuery] = useState("");
  const [itemsToShow, setItemsToShow] = useState(40);
  const [currentPage, setCurrentPage] = useState(1);
  const [hasMorePages, setHasMorePages] = useState(true);

  useEffect(() => {
    const calculateItemsToShow = () => {
      const screenWidth = window.innerWidth;
      if (screenWidth >= 1024) {
        setItemsToShow(40); // 40 items for PC
      } else {
        setItemsToShow(21); // 21 items for mobile
      }
    };

    calculateItemsToShow();
    window.addEventListener('resize', calculateItemsToShow);

    return () => {
      window.removeEventListener('resize', calculateItemsToShow);
    };
  }, []);

  useEffect(() => {
    const fetchNetwork = async () => {
      try {
        const response = await fetch(
          `https://api.themoviedb.org/3/network/${networkId}?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
        );
        const data = await response.json();
        setNetwork(data);
      } catch (error) {
        console.error('Failed to fetch network data:', error);
      }
    };

    const fetchMediaItems = async () => {
      try {
        const response = await fetch(
          `https://api.themoviedb.org/3/discover/tv?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&with_networks=${networkId}&page=${currentPage}`
        );
        const data = await response.json();

        const filteredTvData = data.results.filter(
          (item: any) => item.vote_average > 0 && item.poster_path !== null
        );

        setMediaItems((prevItems) => [
          ...prevItems,
          ...filteredTvData.map((item: any) => ({ ...item, media_type: "tv" })),
        ]);
        setFilteredItems((prevItems) => [
          ...prevItems,
          ...filteredTvData.map((item: any) => ({ ...item, media_type: "tv" })),
        ]);

        setHasMorePages(data.total_pages > currentPage);
      } catch (error) {
        console.error('Failed to fetch media items:', error);
      }
    };

    fetchNetwork();
    fetchMediaItems();
  }, [networkId, currentPage]); // Ensure currentPage is in the dependency array

  const handleLoadMore = () => {
    if (hasMorePages) {
      setCurrentPage((prevPage) => prevPage + 1);
    }
  };

  useEffect(() => {
    const filtered = mediaItems.filter((item) =>
      item.name.toLowerCase().includes(searchQuery.toLowerCase())
    );
    setFilteredItems(filtered);
  }, [searchQuery, mediaItems]);

  const handleSearch = (e: React.ChangeEvent<HTMLInputElement>) => {
    setSearchQuery(e.target.value);
  };

  return (
    <div className="relative mt-0 md:mt-24">
      {network && (
        <div className="relative mb-8 md:mb-12">
          <div className="relative bg-white bg-opacity-90 p-4 flex justify-center items-center h-64 md:h-72">
            <div className="absolute bottom-0 w-full h-16 bg-gradient-to-b from-transparent to-black"></div>
            <img
              src={`https://image.tmdb.org/t/p/original${network.logo_path}`}
              alt={network.name}
              className="h-24 relative z-10"
            />
          </div>

          <div className="absolute bottom-0 left-1/2 transform -translate-x-1/2 translate-y-1/2 w-4/5">
            <input
              type="text"
              value={searchQuery}
              onChange={handleSearch}
              placeholder={`Search for TV series from ${network?.name}`}
              className="w-full bg-black text-white p-4 rounded-lg border-2 border-red-600 focus:outline-none transition-all duration-300 ease-in-out"
            />
          </div>
        </div>
      )}

      <div className="mt-12 grid grid-cols-3 sm:grid-cols-3 md:grid-cols-5 lg:grid-cols-8 gap-4 px-4 animate-fadeIn">
        {filteredItems.slice(0, itemsToShow).map((item) => {
          const slug = `${item.id}-${item.name}`.toLowerCase().replace(/ /g, '-');
          const url = `/watch/tv/?slug=${slug}`;

          return (
            <Link key={item.id} href={url} passHref>
              <div
                className="relative bg-cover bg-center rounded-lg overflow-hidden shadow-lg hover:scale-105 transition-transform duration-300 ease-in-out cursor-pointer animate-shuffle"
                style={{
                  backgroundImage: `url(https://image.tmdb.org/t/p/w500${item.poster_path})`,
                  paddingBottom: '150%',
                }}
              >
                <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-yellow-400 text-xs px-2 py-1 rounded flex items-center">
                  <FaStar className="mr-1" />
                  {item.vote_average.toFixed(1)}
                </div>
              </div>
            </Link>
          );
        })}
      </div>

      {hasMorePages && (
        <div className="flex justify-center mt-8">
          <button
            onClick={handleLoadMore}
            className="px-4 py-2 bg-red-600 text-white rounded hover:bg-red-700"
          >
            Load More
          </button>
        </div>
      )}

      <div className="hidden md:block h-12"></div>

      <style jsx>{`
        .animate-fadeIn {
          animation: fadeIn 1s ease-in-out;
        }

        .animate-shuffle {
          animation: shuffle 0.5s ease-in-out;
        }

        @keyframes fadeIn {
          from {
            opacity: 0;
            transform: translateY(20px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes shuffle {
          from {
            opacity: 0.5;
            transform: scale(0.95);
          }
          to {
            opacity: 1;
            transform: scale(1);
          }
        }
      `}</style>
    </div>
  );
};

export default NetworkPage;
